import React, { useState, useEffect } from 'react';
import '../styles/retro.css';

// ブログ記事のモックデータ
const MOCK_POSTS = [
  {
    id: 1,
    title: "異次元出張レポート",
    author: "山田 量子",
    date: "2024-03-15",
    content: "今日は第7次元への出張でした。時空がねじれる感覚は慣れましたが、まだ少し酔います...",
    likes: 42,
    tags: ["出張", "異次元", "業務報告"]
  },
  {
    id: 2,
    title: "新入社員研修でタイムスリップ",
    author: "鈴木 時空",
    date: "2024-03-14",
    content: "新入社員研修で1985年に行ってきました。バブル前の日本は異次元でした！",
    likes: 38,
    tags: ["研修", "タイムスリップ", "新入社員"]
  },
  // ... 他の記事
];

function BlogPost({ post, onLike }) {
  const [isExpanded, setIsExpanded] = useState(false);

  return (
    <div className="win95-box blog-post">
      <h2 className="blog-title">{post.title}</h2>
      <div className="blog-meta">
        <span className="blog-author">{post.author}</span>
        <span className="blog-date">{post.date}</span>
      </div>
      <div className="blog-content">
        {isExpanded ? post.content : `${post.content.slice(0, 100)}...`}
      </div>
      <div className="blog-tags">
        {post.tags.map(tag => (
          <span key={tag} className="blog-tag">#{tag}</span>
        ))}
      </div>
      <div className="blog-actions">
        <button 
          onClick={() => setIsExpanded(!isExpanded)} 
          className="win95-button"
        >
          {isExpanded ? '閉じる' : '続きを読む'}
        </button>
        <button 
          onClick={() => onLike(post.id)} 
          className="win95-button like-button"
        >
          👍 いいね！ ({post.likes})
        </button>
      </div>
    </div>
  );
}

function Blog() {
  const [posts, setPosts] = useState([]);
  const [loading, setLoading] = useState(true);
  const [filter, setFilter] = useState('');

  useEffect(() => {
    // APIリクエストのシミュレーション
    const fetchPosts = async () => {
      await new Promise(resolve => setTimeout(resolve, 1000));
      setPosts(MOCK_POSTS);
      setLoading(false);
    };

    fetchPosts();
  }, []);

  const handleLike = (postId) => {
    setPosts(posts.map(post => 
      post.id === postId 
        ? { ...post, likes: post.likes + 1 }
        : post
    ));
  };

  const filteredPosts = posts.filter(post =>
    post.title.toLowerCase().includes(filter.toLowerCase()) ||
    post.content.toLowerCase().includes(filter.toLowerCase())
  );

  if (loading) {
    return (
      <div className="win95-box">
        <div className="loading-text blink">
          異次元からデータを読み込み中...
        </div>
      </div>
    );
  }

  return (
    <div className="win95-box">
      <h1 className="glitter">社員ブログ</h1>
      <div className="blog-search">
        <input
          type="text"
          placeholder="記事を検索..."
          value={filter}
          onChange={(e) => setFilter(e.target.value)}
          className="win95-input"
        />
      </div>
      <div className="blog-list">
        {filteredPosts.map(post => (
          <BlogPost 
            key={post.id} 
            post={post} 
            onLike={handleLike}
          />
        ))}
      </div>
    </div>
  );
}

export default Blog; 